# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MappingsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_mapping(self, **kwargs):  # noqa: E501
        """Adds a new mapping.  # noqa: E501

        Adds a new mapping.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_mapping(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddMappingRequest add_mapping_request: The properties of the mapping to be added.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_mapping_with_http_info(**kwargs)  # noqa: E501

    def add_mapping_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a new mapping.  # noqa: E501

        Adds a new mapping.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_mapping_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddMappingRequest add_mapping_request: The properties of the mapping to be added.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Mapping, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_mapping_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_mapping" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_mapping_request' in local_var_params:
            body_params = local_var_params['add_mapping_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_mappings(self, **kwargs):  # noqa: E501
        """Adds new mappings.  # noqa: E501

        Adds new mappings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_mappings(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddMappingRequest] add_mapping_request: The properties of the mappings to be added.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_mappings_with_http_info(**kwargs)  # noqa: E501

    def add_mappings_with_http_info(self, **kwargs):  # noqa: E501
        """Adds new mappings.  # noqa: E501

        Adds new mappings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_mappings_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddMappingRequest] add_mapping_request: The properties of the mappings to be added.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Mapping], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_mapping_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_mappings" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_mapping_request' in local_var_params:
            body_params = local_var_params['add_mapping_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Mapping]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mapping(self, mapping_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its id.  # noqa: E501

        Changes the mapping identified by its <code>id</code>.<p>Change the mapping identified by its <code>id</code> with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str mapping_id: The ID of the mapping to be changed. (required)
        :param ChangeMappingRequest change_mapping_request: The properties of the mapping to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_mapping_with_http_info(mapping_id, **kwargs)  # noqa: E501

    def change_mapping_with_http_info(self, mapping_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its id.  # noqa: E501

        Changes the mapping identified by its <code>id</code>.<p>Change the mapping identified by its <code>id</code> with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping_with_http_info(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str mapping_id: The ID of the mapping to be changed. (required)
        :param ChangeMappingRequest change_mapping_request: The properties of the mapping to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Mapping, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'mapping_id',
            'change_mapping_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mapping" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'mapping_id' is set
        if self.api_client.client_side_validation and ('mapping_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['mapping_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mapping_id` when calling `change_mapping`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'mapping_id' in local_var_params:
            path_params['mappingId'] = local_var_params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_mapping_request' in local_var_params:
            body_params = local_var_params['change_mapping_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/{mappingId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mapping_by_external_entity(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its external ids.  # noqa: E501

        Changes the mapping identified by its external <code>id</code>s.<p>Changes the mapping identified by its external <code>id</code>s with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping_by_external_entity(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: The external system ID of the mapping to be changed. (required)
        :param str external_entity_id: The external entity ID of the mapping to be changed. (required)
        :param ChangeMappingByExternalEntityRequest change_mapping_by_external_entity_request: The properties of the mapping to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, **kwargs)  # noqa: E501

    def change_mapping_by_external_entity_with_http_info(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its external ids.  # noqa: E501

        Changes the mapping identified by its external <code>id</code>s.<p>Changes the mapping identified by its external <code>id</code>s with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: The external system ID of the mapping to be changed. (required)
        :param str external_entity_id: The external entity ID of the mapping to be changed. (required)
        :param ChangeMappingByExternalEntityRequest change_mapping_by_external_entity_request: The properties of the mapping to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Mapping, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'external_system_id',
            'external_entity_id',
            'change_mapping_by_external_entity_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mapping_by_external_entity" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if self.api_client.client_side_validation and ('external_system_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['external_system_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_system_id` when calling `change_mapping_by_external_entity`")  # noqa: E501
        # verify the required parameter 'external_entity_id' is set
        if self.api_client.client_side_validation and ('external_entity_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['external_entity_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_entity_id` when calling `change_mapping_by_external_entity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in local_var_params:
            path_params['externalSystemId'] = local_var_params['external_system_id']  # noqa: E501
        if 'external_entity_id' in local_var_params:
            path_params['externalEntityId'] = local_var_params['external_entity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_mapping_by_external_entity_request' in local_var_params:
            body_params = local_var_params['change_mapping_by_external_entity_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/externalEntity/{externalEntityId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mapping_by_mapped_resource(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its external system id and mapped resource id.  # noqa: E501

        Changes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.<p>Changes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code> with the information that is present in the requests. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping_by_mapped_resource(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: The external system id of the mapping to be changed. (required)
        :param str mapped_resource_id: The mapped resource id of the mapping to be changed. (required)
        :param ChangeMappingByMappedResourceRequest change_mapping_by_mapped_resource_request: The properties of the mapping to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, **kwargs)  # noqa: E501

    def change_mapping_by_mapped_resource_with_http_info(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its external system id and mapped resource id.  # noqa: E501

        Changes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.<p>Changes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code> with the information that is present in the requests. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: The external system id of the mapping to be changed. (required)
        :param str mapped_resource_id: The mapped resource id of the mapping to be changed. (required)
        :param ChangeMappingByMappedResourceRequest change_mapping_by_mapped_resource_request: The properties of the mapping to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Mapping, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'external_system_id',
            'mapped_resource_id',
            'change_mapping_by_mapped_resource_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mapping_by_mapped_resource" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if self.api_client.client_side_validation and ('external_system_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['external_system_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_system_id` when calling `change_mapping_by_mapped_resource`")  # noqa: E501
        # verify the required parameter 'mapped_resource_id' is set
        if self.api_client.client_side_validation and ('mapped_resource_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['mapped_resource_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mapped_resource_id` when calling `change_mapping_by_mapped_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in local_var_params:
            path_params['externalSystemId'] = local_var_params['external_system_id']  # noqa: E501
        if 'mapped_resource_id' in local_var_params:
            path_params['mappedResourceId'] = local_var_params['mapped_resource_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_mapping_by_mapped_resource_request' in local_var_params:
            body_params = local_var_params['change_mapping_by_mapped_resource_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/mappedResource/{mappedResourceId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mappings(self, **kwargs):  # noqa: E501
        """Changes multiple mappings identified by their ids.  # noqa: E501

        Changes multiple mappings identified by their <code>id</code>s.<p>Change the mappings identified by its <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeMappingRequest] change_mapping_request: The properties of the mappings to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_mappings_with_http_info(**kwargs)  # noqa: E501

    def change_mappings_with_http_info(self, **kwargs):  # noqa: E501
        """Changes multiple mappings identified by their ids.  # noqa: E501

        Changes multiple mappings identified by their <code>id</code>s.<p>Change the mappings identified by its <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeMappingRequest] change_mapping_request: The properties of the mappings to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Mapping], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'change_mapping_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mappings" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_mapping_request' in local_var_params:
            body_params = local_var_params['change_mapping_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Mapping]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mappings_by_external_entities(self, **kwargs):  # noqa: E501
        """Changes the mappings identified by their external ids.  # noqa: E501

        Changes the mappings identified by their external <code>id</code>s.<p>Changes the mappings identified by their external <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings_by_external_entities(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeMappingByExternalEntityRequest] change_mapping_by_external_entity_request: The properties of the mappings to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_mappings_by_external_entities_with_http_info(**kwargs)  # noqa: E501

    def change_mappings_by_external_entities_with_http_info(self, **kwargs):  # noqa: E501
        """Changes the mappings identified by their external ids.  # noqa: E501

        Changes the mappings identified by their external <code>id</code>s.<p>Changes the mappings identified by their external <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings_by_external_entities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeMappingByExternalEntityRequest] change_mapping_by_external_entity_request: The properties of the mappings to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Mapping], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'change_mapping_by_external_entity_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mappings_by_external_entities" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_mapping_by_external_entity_request' in local_var_params:
            body_params = local_var_params['change_mapping_by_external_entity_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/externalEntity/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Mapping]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mappings_by_mapped_resources(self, **kwargs):  # noqa: E501
        """Changes the mapping identified by their external system ids and mapped resource ids.  # noqa: E501

        Changes the mapping identified by their external system <code>id</code>s and mapped resource <code>id</code>s.<p>Changes the mapping identified by their external system <code>id</code>s and mapped resource <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings_by_mapped_resources(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeMappingByMappedResourceRequest] change_mapping_by_mapped_resource_request: The properties of the mappings to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_mappings_by_mapped_resources_with_http_info(**kwargs)  # noqa: E501

    def change_mappings_by_mapped_resources_with_http_info(self, **kwargs):  # noqa: E501
        """Changes the mapping identified by their external system ids and mapped resource ids.  # noqa: E501

        Changes the mapping identified by their external system <code>id</code>s and mapped resource <code>id</code>s.<p>Changes the mapping identified by their external system <code>id</code>s and mapped resource <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings_by_mapped_resources_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeMappingByMappedResourceRequest] change_mapping_by_mapped_resource_request: The properties of the mappings to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Mapping], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'change_mapping_by_mapped_resource_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mappings_by_mapped_resources" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_mapping_by_mapped_resource_request' in local_var_params:
            body_params = local_var_params['change_mapping_by_mapped_resource_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/mappedResource/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Mapping]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_mappings(self, **kwargs):  # noqa: E501
        """Returns mappings matching the given search criteria.  # noqa: E501

        Returns mappings matching the given search criteria.<p>Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored.</p>The returned synchronization information satisfies all constraints that are specified in this search criteria. By default a result containing 1000 mappings is returned.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_mappings(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str external_system_id: The ID of the external system that the mapped resource belongs to.
        :param str mapped_resource_type: The type of the mapped resource.
        :param str sync_action: The type of the action performed during last successful synchronization.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MappingPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_mappings_with_http_info(**kwargs)  # noqa: E501

    def find_mappings_with_http_info(self, **kwargs):  # noqa: E501
        """Returns mappings matching the given search criteria.  # noqa: E501

        Returns mappings matching the given search criteria.<p>Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored.</p>The returned synchronization information satisfies all constraints that are specified in this search criteria. By default a result containing 1000 mappings is returned.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_mappings_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str external_system_id: The ID of the external system that the mapped resource belongs to.
        :param str mapped_resource_type: The type of the mapped resource.
        :param str sync_action: The type of the action performed during last successful synchronization.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MappingPagedResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit',
            'count_limit',
            'external_system_id',
            'mapped_resource_type',
            'sync_action'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_mappings" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and ('external_system_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_system_id']) > 36):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_system_id` when calling `find_mappings`, length must be less than or equal to `36`")  # noqa: E501
        if self.api_client.client_side_validation and ('external_system_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_system_id']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_system_id` when calling `find_mappings`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'count_limit' in local_var_params and local_var_params['count_limit'] is not None:  # noqa: E501
            query_params.append(('countLimit', local_var_params['count_limit']))  # noqa: E501
        if 'external_system_id' in local_var_params and local_var_params['external_system_id'] is not None:  # noqa: E501
            query_params.append(('externalSystemId', local_var_params['external_system_id']))  # noqa: E501
        if 'mapped_resource_type' in local_var_params and local_var_params['mapped_resource_type'] is not None:  # noqa: E501
            query_params.append(('mappedResourceType', local_var_params['mapped_resource_type']))  # noqa: E501
        if 'sync_action' in local_var_params and local_var_params['sync_action'] is not None:  # noqa: E501
            query_params.append(('syncAction', local_var_params['sync_action']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MappingPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_mapping(self, mapping_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by given id.  # noqa: E501

        Returns a mapping identified by given <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str mapping_id: The id of the mapping. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_mapping_with_http_info(mapping_id, **kwargs)  # noqa: E501

    def get_mapping_with_http_info(self, mapping_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by given id.  # noqa: E501

        Returns a mapping identified by given <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping_with_http_info(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str mapping_id: The id of the mapping. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Mapping, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'mapping_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_mapping" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'mapping_id' is set
        if self.api_client.client_side_validation and ('mapping_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['mapping_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mapping_id` when calling `get_mapping`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'mapping_id' in local_var_params:
            path_params['mappingId'] = local_var_params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/{mappingId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_mapping_by_external_entity(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by its external ids.  # noqa: E501

        Returns a mapping identified by its external <code>id</code>s.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping_by_external_entity(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: (required)
        :param str external_entity_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, **kwargs)  # noqa: E501

    def get_mapping_by_external_entity_with_http_info(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by its external ids.  # noqa: E501

        Returns a mapping identified by its external <code>id</code>s.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: (required)
        :param str external_entity_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Mapping, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'external_system_id',
            'external_entity_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_mapping_by_external_entity" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if self.api_client.client_side_validation and ('external_system_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['external_system_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_system_id` when calling `get_mapping_by_external_entity`")  # noqa: E501
        # verify the required parameter 'external_entity_id' is set
        if self.api_client.client_side_validation and ('external_entity_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['external_entity_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_entity_id` when calling `get_mapping_by_external_entity`")  # noqa: E501

        if self.api_client.client_side_validation and ('external_system_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_system_id']) > 36):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_system_id` when calling `get_mapping_by_external_entity`, length must be less than or equal to `36`")  # noqa: E501
        if self.api_client.client_side_validation and ('external_system_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_system_id']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_system_id` when calling `get_mapping_by_external_entity`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('external_entity_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_entity_id']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_entity_id` when calling `get_mapping_by_external_entity`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('external_entity_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_entity_id']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_entity_id` when calling `get_mapping_by_external_entity`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'external_system_id' in local_var_params:
            path_params['externalSystemId'] = local_var_params['external_system_id']  # noqa: E501
        if 'external_entity_id' in local_var_params:
            path_params['externalEntityId'] = local_var_params['external_entity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/externalEntity/{externalEntityId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_mapping_by_mapped_resource(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by its external system id and mapped resource id.  # noqa: E501

        Returns a mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping_by_mapped_resource(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: (required)
        :param str mapped_resource_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, **kwargs)  # noqa: E501

    def get_mapping_by_mapped_resource_with_http_info(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by its external system id and mapped resource id.  # noqa: E501

        Returns a mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: (required)
        :param str mapped_resource_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Mapping, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'external_system_id',
            'mapped_resource_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_mapping_by_mapped_resource" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if self.api_client.client_side_validation and ('external_system_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['external_system_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_system_id` when calling `get_mapping_by_mapped_resource`")  # noqa: E501
        # verify the required parameter 'mapped_resource_id' is set
        if self.api_client.client_side_validation and ('mapped_resource_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['mapped_resource_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mapped_resource_id` when calling `get_mapping_by_mapped_resource`")  # noqa: E501

        if self.api_client.client_side_validation and ('external_system_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_system_id']) > 36):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_system_id` when calling `get_mapping_by_mapped_resource`, length must be less than or equal to `36`")  # noqa: E501
        if self.api_client.client_side_validation and ('external_system_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_system_id']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_system_id` when calling `get_mapping_by_mapped_resource`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'external_system_id' in local_var_params:
            path_params['externalSystemId'] = local_var_params['external_system_id']  # noqa: E501
        if 'mapped_resource_id' in local_var_params:
            path_params['mappedResourceId'] = local_var_params['mapped_resource_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/mappedResource/{mappedResourceId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_mapping(self, mapping_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its id.  # noqa: E501

        Removes the mapping identified by its <code>id</code>.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str mapping_id: The id of the mapping. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_mapping_with_http_info(mapping_id, **kwargs)  # noqa: E501

    def remove_mapping_with_http_info(self, mapping_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its id.  # noqa: E501

        Removes the mapping identified by its <code>id</code>.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping_with_http_info(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str mapping_id: The id of the mapping. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'mapping_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_mapping" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'mapping_id' is set
        if self.api_client.client_side_validation and ('mapping_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['mapping_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mapping_id` when calling `remove_mapping`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'mapping_id' in local_var_params:
            path_params['mappingId'] = local_var_params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/{mappingId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_mapping_by_external_entity(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its external ids.  # noqa: E501

        Removes the mapping identified by its external <code>id</code>s.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping_by_external_entity(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: The external system id of the mapping to be removed. (required)
        :param str external_entity_id: The external entity id of the mapping to be removed. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, **kwargs)  # noqa: E501

    def remove_mapping_by_external_entity_with_http_info(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its external ids.  # noqa: E501

        Removes the mapping identified by its external <code>id</code>s.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: The external system id of the mapping to be removed. (required)
        :param str external_entity_id: The external entity id of the mapping to be removed. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'external_system_id',
            'external_entity_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_mapping_by_external_entity" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if self.api_client.client_side_validation and ('external_system_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['external_system_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_system_id` when calling `remove_mapping_by_external_entity`")  # noqa: E501
        # verify the required parameter 'external_entity_id' is set
        if self.api_client.client_side_validation and ('external_entity_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['external_entity_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_entity_id` when calling `remove_mapping_by_external_entity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in local_var_params:
            path_params['externalSystemId'] = local_var_params['external_system_id']  # noqa: E501
        if 'external_entity_id' in local_var_params:
            path_params['externalEntityId'] = local_var_params['external_entity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/externalEntity/{externalEntityId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_mapping_by_mapped_resource(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its external system id and mapped resource id.  # noqa: E501

        Removes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping_by_mapped_resource(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: The external system id of the mapping to be changed. (required)
        :param str mapped_resource_id: The mapped resource id of the mapping to be changed. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, **kwargs)  # noqa: E501

    def remove_mapping_by_mapped_resource_with_http_info(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its external system id and mapped resource id.  # noqa: E501

        Removes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: The external system id of the mapping to be changed. (required)
        :param str mapped_resource_id: The mapped resource id of the mapping to be changed. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'external_system_id',
            'mapped_resource_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_mapping_by_mapped_resource" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if self.api_client.client_side_validation and ('external_system_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['external_system_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_system_id` when calling `remove_mapping_by_mapped_resource`")  # noqa: E501
        # verify the required parameter 'mapped_resource_id' is set
        if self.api_client.client_side_validation and ('mapped_resource_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['mapped_resource_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mapped_resource_id` when calling `remove_mapping_by_mapped_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in local_var_params:
            path_params['externalSystemId'] = local_var_params['external_system_id']  # noqa: E501
        if 'mapped_resource_id' in local_var_params:
            path_params['mappedResourceId'] = local_var_params['mapped_resource_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/mappedResource/{mappedResourceId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_mappings_by_external_system_in_job(self, external_system_id, **kwargs):  # noqa: E501
        """Removes all the mappings identified by given external system id.  # noqa: E501

        Removes all the mappings identified by given external system <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mappings_by_external_system_in_job(external_system_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: The id of the external system of the mappings that will be removed. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_mappings_by_external_system_in_job_with_http_info(external_system_id, **kwargs)  # noqa: E501

    def remove_mappings_by_external_system_in_job_with_http_info(self, external_system_id, **kwargs):  # noqa: E501
        """Removes all the mappings identified by given external system id.  # noqa: E501

        Removes all the mappings identified by given external system <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mappings_by_external_system_in_job_with_http_info(external_system_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str external_system_id: The id of the external system of the mappings that will be removed. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Job, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'external_system_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_mappings_by_external_system_in_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if self.api_client.client_side_validation and ('external_system_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['external_system_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_system_id` when calling `remove_mappings_by_external_system_in_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in local_var_params:
            path_params['externalSystemId'] = local_var_params['external_system_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/removalJobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_mappings_in_job(self, **kwargs):  # noqa: E501
        """Removes multiple mappings in job.  # noqa: E501

        Removes multiple mappings in job.<p>If any mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mappings_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: The ids of the mappings to be removed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_mappings_in_job_with_http_info(**kwargs)  # noqa: E501

    def remove_mappings_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Removes multiple mappings in job.  # noqa: E501

        Removes multiple mappings in job.<p>If any mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mappings_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: The ids of the mappings to be removed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Job, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_mappings_in_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/removalJobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class WorkflowInstancesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel_workflow_instances(self, workflow_instance_id, **kwargs):  # noqa: E501
        """Cancel workflow instance.  # noqa: E501

        Cancels the workflow instance with the specified ID with a reason. Canceling the workflow instance also cancels the workflow sub-processes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_workflow_instances(workflow_instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_instance_id: The identifier of the workflow instance to be cancelled. (required)
        :param str body: The reason for the cancellation of the workflow instance.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.cancel_workflow_instances_with_http_info(workflow_instance_id, **kwargs)  # noqa: E501

    def cancel_workflow_instances_with_http_info(self, workflow_instance_id, **kwargs):  # noqa: E501
        """Cancel workflow instance.  # noqa: E501

        Cancels the workflow instance with the specified ID with a reason. Canceling the workflow instance also cancels the workflow sub-processes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_workflow_instances_with_http_info(workflow_instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_instance_id: The identifier of the workflow instance to be cancelled. (required)
        :param str body: The reason for the cancellation of the workflow instance.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_instance_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_workflow_instances" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_instance_id' is set
        if self.api_client.client_side_validation and ('workflow_instance_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_instance_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_instance_id` when calling `cancel_workflow_instances`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_instance_id' in local_var_params:
            path_params['workflowInstanceId'] = local_var_params['workflow_instance_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances/{workflowInstanceId}/canceled', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_workflow_instances(self, **kwargs):  # noqa: E501
        """Find workflow instances.  # noqa: E501

        Returns workflow instances matching given search criteria.<p>Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned workflow instances satisfy all constraints that are specified in this search criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_workflow_instances(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str business_item_name: The display name of the business item that should be contained by the searched workflows.
        :param str business_item_id: The ID of the business item that should be contained by the searched workflows.
        :param str workflow_definition_id: The ID of the workflow definition.
        :param str sort_field: The field on which the results are sorted.
        :param str sort_order: The sorting order.
        :param str parent_workflow_instance_id: The ID of the parent workflow instance.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_workflow_instances_with_http_info(**kwargs)  # noqa: E501

    def find_workflow_instances_with_http_info(self, **kwargs):  # noqa: E501
        """Find workflow instances.  # noqa: E501

        Returns workflow instances matching given search criteria.<p>Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned workflow instances satisfy all constraints that are specified in this search criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_workflow_instances_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str business_item_name: The display name of the business item that should be contained by the searched workflows.
        :param str business_item_id: The ID of the business item that should be contained by the searched workflows.
        :param str workflow_definition_id: The ID of the workflow definition.
        :param str sort_field: The field on which the results are sorted.
        :param str sort_order: The sorting order.
        :param str parent_workflow_instance_id: The ID of the parent workflow instance.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PagedResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit',
            'count_limit',
            'business_item_name',
            'business_item_id',
            'workflow_definition_id',
            'sort_field',
            'sort_order',
            'parent_workflow_instance_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_workflow_instances" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'count_limit' in local_var_params and local_var_params['count_limit'] is not None:  # noqa: E501
            query_params.append(('countLimit', local_var_params['count_limit']))  # noqa: E501
        if 'business_item_name' in local_var_params and local_var_params['business_item_name'] is not None:  # noqa: E501
            query_params.append(('businessItemName', local_var_params['business_item_name']))  # noqa: E501
        if 'business_item_id' in local_var_params and local_var_params['business_item_id'] is not None:  # noqa: E501
            query_params.append(('businessItemId', local_var_params['business_item_id']))  # noqa: E501
        if 'workflow_definition_id' in local_var_params and local_var_params['workflow_definition_id'] is not None:  # noqa: E501
            query_params.append(('workflowDefinitionId', local_var_params['workflow_definition_id']))  # noqa: E501
        if 'sort_field' in local_var_params and local_var_params['sort_field'] is not None:  # noqa: E501
            query_params.append(('sortField', local_var_params['sort_field']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('sortOrder', local_var_params['sort_order']))  # noqa: E501
        if 'parent_workflow_instance_id' in local_var_params and local_var_params['parent_workflow_instance_id'] is not None:  # noqa: E501
            query_params.append(('parentWorkflowInstanceId', local_var_params['parent_workflow_instance_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workflow_instance_diagram(self, workflow_instance_id, **kwargs):  # noqa: E501
        """Returns the file representing the diagram of workflow instance identified by the given ID.  # noqa: E501

        Returns the file representing the diagram of workflow instance identified by the given ID. The diagram input stream returned can be null as deployed workflow defintions without graphical notation included don't have a diagram  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_instance_diagram(workflow_instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_instance_id: The ID of the workflow instance to return the diagram for. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_workflow_instance_diagram_with_http_info(workflow_instance_id, **kwargs)  # noqa: E501

    def get_workflow_instance_diagram_with_http_info(self, workflow_instance_id, **kwargs):  # noqa: E501
        """Returns the file representing the diagram of workflow instance identified by the given ID.  # noqa: E501

        Returns the file representing the diagram of workflow instance identified by the given ID. The diagram input stream returned can be null as deployed workflow defintions without graphical notation included don't have a diagram  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_instance_diagram_with_http_info(workflow_instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_instance_id: The ID of the workflow instance to return the diagram for. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_instance_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_instance_diagram" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_instance_id' is set
        if self.api_client.client_side_validation and ('workflow_instance_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_instance_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_instance_id` when calling `get_workflow_instance_diagram`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_instance_id' in local_var_params:
            path_params['workflowInstanceId'] = local_var_params['workflow_instance_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['image/png'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances/{workflowInstanceId}/diagram', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def message_event_received(self, process_instance_id, message_name, **kwargs):  # noqa: E501
        """Pass message event to workflow engine.  # noqa: E501

        Passes the message event to the workflow engine. It will pass on this specific event to the engine with the given name, process instance and variables.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.message_event_received(process_instance_id, message_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str process_instance_id: The ID of an instance of a process. Given process instance should have only one execution running at the time. Otherwise this method will fail. (required)
        :param str message_name: The name of the message to trigger. (required)
        :param MessageEventReceivedRequest message_event_received_request: The properties of the message event to be received.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.message_event_received_with_http_info(process_instance_id, message_name, **kwargs)  # noqa: E501

    def message_event_received_with_http_info(self, process_instance_id, message_name, **kwargs):  # noqa: E501
        """Pass message event to workflow engine.  # noqa: E501

        Passes the message event to the workflow engine. It will pass on this specific event to the engine with the given name, process instance and variables.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.message_event_received_with_http_info(process_instance_id, message_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str process_instance_id: The ID of an instance of a process. Given process instance should have only one execution running at the time. Otherwise this method will fail. (required)
        :param str message_name: The name of the message to trigger. (required)
        :param MessageEventReceivedRequest message_event_received_request: The properties of the message event to be received.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'process_instance_id',
            'message_name',
            'message_event_received_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method message_event_received" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'process_instance_id' is set
        if self.api_client.client_side_validation and ('process_instance_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['process_instance_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `process_instance_id` when calling `message_event_received`")  # noqa: E501
        # verify the required parameter 'message_name' is set
        if self.api_client.client_side_validation and ('message_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['message_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `message_name` when calling `message_event_received`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'process_instance_id' in local_var_params:
            path_params['processInstanceId'] = local_var_params['process_instance_id']  # noqa: E501
        if 'message_name' in local_var_params:
            path_params['messageName'] = local_var_params['message_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'message_event_received_request' in local_var_params:
            body_params = local_var_params['message_event_received_request']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances/{processInstanceId}/messageEvents/{messageName}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_workflow_instances(self, **kwargs):  # noqa: E501
        """Start workflow instances.  # noqa: E501

        Starts multiple workflow instances based on the provided request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_workflow_instances(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StartWorkflowInstancesRequest start_workflow_instances_request: The properties of the workflow to be started.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[WorkflowInstance]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_workflow_instances_with_http_info(**kwargs)  # noqa: E501

    def start_workflow_instances_with_http_info(self, **kwargs):  # noqa: E501
        """Start workflow instances.  # noqa: E501

        Starts multiple workflow instances based on the provided request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_workflow_instances_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StartWorkflowInstancesRequest start_workflow_instances_request: The properties of the workflow to be started.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[WorkflowInstance], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'start_workflow_instances_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_workflow_instances" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'start_workflow_instances_request' in local_var_params:
            body_params = local_var_params['start_workflow_instances_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[WorkflowInstance]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_workflow_instances_in_job(self, **kwargs):  # noqa: E501
        """Start workflow instances.  # noqa: E501

        Starts multiple workflow instances asynchronously based on the provided request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_workflow_instances_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StartWorkflowInstancesRequest start_workflow_instances_request: Properties of the workflow to be started.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_workflow_instances_in_job_with_http_info(**kwargs)  # noqa: E501

    def start_workflow_instances_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Start workflow instances.  # noqa: E501

        Starts multiple workflow instances asynchronously based on the provided request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_workflow_instances_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StartWorkflowInstancesRequest start_workflow_instances_request: Properties of the workflow to be started.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Job, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'start_workflow_instances_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_workflow_instances_in_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'start_workflow_instances_request' in local_var_params:
            body_params = local_var_params['start_workflow_instances_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances/startJobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class AddRelationRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source_id': 'str',
        'target_id': 'str',
        'type_id': 'str',
        'starting_date': 'int',
        'ending_date': 'int'
    }

    attribute_map = {
        'source_id': 'sourceId',
        'target_id': 'targetId',
        'type_id': 'typeId',
        'starting_date': 'startingDate',
        'ending_date': 'endingDate'
    }

    def __init__(self, source_id=None, target_id=None, type_id=None, starting_date=None, ending_date=None, local_vars_configuration=None):  # noqa: E501
        """AddRelationRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._source_id = None
        self._target_id = None
        self._type_id = None
        self._starting_date = None
        self._ending_date = None
        self.discriminator = None

        self.source_id = source_id
        self.target_id = target_id
        self.type_id = type_id
        if starting_date is not None:
            self.starting_date = starting_date
        if ending_date is not None:
            self.ending_date = ending_date

    @property
    def source_id(self):
        """Gets the source_id of this AddRelationRequest.  # noqa: E501

        The ID of the source of the relation.  # noqa: E501

        :return: The source_id of this AddRelationRequest.  # noqa: E501
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """Sets the source_id of this AddRelationRequest.

        The ID of the source of the relation.  # noqa: E501

        :param source_id: The source_id of this AddRelationRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source_id is None:  # noqa: E501
            raise ValueError("Invalid value for `source_id`, must not be `None`")  # noqa: E501

        self._source_id = source_id

    @property
    def target_id(self):
        """Gets the target_id of this AddRelationRequest.  # noqa: E501

        The ID of the target of the relation.  # noqa: E501

        :return: The target_id of this AddRelationRequest.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this AddRelationRequest.

        The ID of the target of the relation.  # noqa: E501

        :param target_id: The target_id of this AddRelationRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and target_id is None:  # noqa: E501
            raise ValueError("Invalid value for `target_id`, must not be `None`")  # noqa: E501

        self._target_id = target_id

    @property
    def type_id(self):
        """Gets the type_id of this AddRelationRequest.  # noqa: E501

        The ID of the type of the relation.  # noqa: E501

        :return: The type_id of this AddRelationRequest.  # noqa: E501
        :rtype: str
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this AddRelationRequest.

        The ID of the type of the relation.  # noqa: E501

        :param type_id: The type_id of this AddRelationRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `type_id`, must not be `None`")  # noqa: E501

        self._type_id = type_id

    @property
    def starting_date(self):
        """Gets the starting_date of this AddRelationRequest.  # noqa: E501

        The starting date of the relation.  # noqa: E501

        :return: The starting_date of this AddRelationRequest.  # noqa: E501
        :rtype: int
        """
        return self._starting_date

    @starting_date.setter
    def starting_date(self, starting_date):
        """Sets the starting_date of this AddRelationRequest.

        The starting date of the relation.  # noqa: E501

        :param starting_date: The starting_date of this AddRelationRequest.  # noqa: E501
        :type: int
        """

        self._starting_date = starting_date

    @property
    def ending_date(self):
        """Gets the ending_date of this AddRelationRequest.  # noqa: E501

        The ending date of the relation.  # noqa: E501

        :return: The ending_date of this AddRelationRequest.  # noqa: E501
        :rtype: int
        """
        return self._ending_date

    @ending_date.setter
    def ending_date(self, ending_date):
        """Sets the ending_date of this AddRelationRequest.

        The ending date of the relation.  # noqa: E501

        :param ending_date: The ending_date of this AddRelationRequest.  # noqa: E501
        :type: int
        """

        self._ending_date = ending_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddRelationRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddRelationRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class CharacteristicTypeAssignmentReference(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'min': 'int',
        'max': 'int',
        'type': 'str',
        'relation_type_direction': 'str',
        'relation_type_restriction': 'str'
    }

    attribute_map = {
        'id': 'id',
        'min': 'min',
        'max': 'max',
        'type': 'type',
        'relation_type_direction': 'relationTypeDirection',
        'relation_type_restriction': 'relationTypeRestriction'
    }

    def __init__(self, id=None, min=None, max=None, type=None, relation_type_direction=None, relation_type_restriction=None, local_vars_configuration=None):  # noqa: E501
        """CharacteristicTypeAssignmentReference - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._min = None
        self._max = None
        self._type = None
        self._relation_type_direction = None
        self._relation_type_restriction = None
        self.discriminator = None

        self.id = id
        if min is not None:
            self.min = min
        if max is not None:
            self.max = max
        self.type = type
        if relation_type_direction is not None:
            self.relation_type_direction = relation_type_direction
        if relation_type_restriction is not None:
            self.relation_type_restriction = relation_type_restriction

    @property
    def id(self):
        """Gets the id of this CharacteristicTypeAssignmentReference.  # noqa: E501

        The ID of the reference.  # noqa: E501

        :return: The id of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CharacteristicTypeAssignmentReference.

        The ID of the reference.  # noqa: E501

        :param id: The id of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def min(self):
        """Gets the min of this CharacteristicTypeAssignmentReference.  # noqa: E501

        The minimum allowed.  # noqa: E501

        :return: The min of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :rtype: int
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this CharacteristicTypeAssignmentReference.

        The minimum allowed.  # noqa: E501

        :param min: The min of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                min is not None and min < 0):  # noqa: E501
            raise ValueError("Invalid value for `min`, must be a value greater than or equal to `0`")  # noqa: E501

        self._min = min

    @property
    def max(self):
        """Gets the max of this CharacteristicTypeAssignmentReference.  # noqa: E501

        The maximum allowed, unlimited when null.  # noqa: E501

        :return: The max of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :rtype: int
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this CharacteristicTypeAssignmentReference.

        The maximum allowed, unlimited when null.  # noqa: E501

        :param max: The max of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :type: int
        """

        self._max = max

    @property
    def type(self):
        """Gets the type of this CharacteristicTypeAssignmentReference.  # noqa: E501

        The resource type.  # noqa: E501

        :return: The type of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CharacteristicTypeAssignmentReference.

        The resource type.  # noqa: E501

        :param type: The type of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["View", "Asset", "Community", "Domain", "AssetType", "DomainType", "Status", "User", "ClassificationMatch", "UserGroup", "Attribute", "StringAttribute", "ScriptAttribute", "BooleanAttribute", "DateAttribute", "NumericAttribute", "SingleValueListAttribute", "MultiValueListAttribute", "Comment", "Attachment", "Responsibility", "Workflow", "Job", "Relation", "RelationType", "ComplexRelation", "ComplexRelationType", "ArticulationRule", "Assignment", "Scope", "RelationTrace", "ValidationRule", "DataQualityRule", "DataQualityMetric", "Address", "InstantMessagingAccount", "Email", "PhoneNumber", "Website", "Activity", "FormProperty", "WorkflowTask", "ActivityChange", "WorkflowInstance", "Role", "AttributeType", "BooleanAttributeType", "DateAttributeType", "DateTimeAttributeType", "MultiValueListAttributeType", "NumericAttributeType", "ScriptAttributeType", "SingleValueListAttributeType", "StringAttributeType", "ViewSharingRule", "ViewAssignmentRule", "JdbcDriverFile", "JdbcDriver", "JdbcIngestionProperties", "CsvIngestionProperties", "ExcelIngestionProperties", "ConnectionStringParameter", "AssignedCharacteristicType", "Notification", "Tag", "ComplexRelationLegType", "ComplexRelationAttributeType", "ComplexRelationLeg", "BaseDataType", "AdvancedDataType", "DiagramPicture", "DiagramPictureSharingRule", "DiagramPictureAssignmentRule", "Rating", "Classification", "PhysicalDataConnector", "Context"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def relation_type_direction(self):
        """Gets the relation_type_direction of this CharacteristicTypeAssignmentReference.  # noqa: E501

        The relation type direction, if the referenced resource is a relation type; otherwise null.  # noqa: E501

        :return: The relation_type_direction of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :rtype: str
        """
        return self._relation_type_direction

    @relation_type_direction.setter
    def relation_type_direction(self, relation_type_direction):
        """Sets the relation_type_direction of this CharacteristicTypeAssignmentReference.

        The relation type direction, if the referenced resource is a relation type; otherwise null.  # noqa: E501

        :param relation_type_direction: The relation_type_direction of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :type: str
        """
        allowed_values = ["TO_SOURCE", "TO_TARGET", "BOTH", "NONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and relation_type_direction not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `relation_type_direction` ({0}), must be one of {1}"  # noqa: E501
                .format(relation_type_direction, allowed_values)
            )

        self._relation_type_direction = relation_type_direction

    @property
    def relation_type_restriction(self):
        """Gets the relation_type_restriction of this CharacteristicTypeAssignmentReference.  # noqa: E501

        The relation type restriction of the target Asset Type, if the referenced resource is a relation type; otherwise null. When specified, it effectively replaces the source asset type of the relation when relationTypeDirection = TO_SOURCE or the target asset type of the relation when relationTypeDirection = TO_TARGET.You can specify the relation type restriction only when relationTypeDirection is not null. If specified, it must be an ID of a subtype of the source or target asset type, depending on the value of relationTypeDirection.  # noqa: E501

        :return: The relation_type_restriction of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :rtype: str
        """
        return self._relation_type_restriction

    @relation_type_restriction.setter
    def relation_type_restriction(self, relation_type_restriction):
        """Sets the relation_type_restriction of this CharacteristicTypeAssignmentReference.

        The relation type restriction of the target Asset Type, if the referenced resource is a relation type; otherwise null. When specified, it effectively replaces the source asset type of the relation when relationTypeDirection = TO_SOURCE or the target asset type of the relation when relationTypeDirection = TO_TARGET.You can specify the relation type restriction only when relationTypeDirection is not null. If specified, it must be an ID of a subtype of the source or target asset type, depending on the value of relationTypeDirection.  # noqa: E501

        :param relation_type_restriction: The relation_type_restriction of this CharacteristicTypeAssignmentReference.  # noqa: E501
        :type: str
        """

        self._relation_type_restriction = relation_type_restriction

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CharacteristicTypeAssignmentReference):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CharacteristicTypeAssignmentReference):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.relation_types_api import RelationTypesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestRelationTypesApi(unittest.TestCase):
    """RelationTypesApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.relation_types_api.RelationTypesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_relation_type(self):
        """Test case for add_relation_type

        Adds a new relation type.  # noqa: E501
        """
        pass

    def test_add_relation_types(self):
        """Test case for add_relation_types

        Adds multiple new relation type.  # noqa: E501
        """
        pass

    def test_change_relation_type(self):
        """Test case for change_relation_type

        Changes the relation type.  # noqa: E501
        """
        pass

    def test_change_relation_types(self):
        """Test case for change_relation_types

        Changes the relation types.  # noqa: E501
        """
        pass

    def test_find_relation_types(self):
        """Test case for find_relation_types

        Finds all the relation types matching the given criteria.  # noqa: E501
        """
        pass

    def test_get_relation_type(self):
        """Test case for get_relation_type

        Returns relation type identified by given UUID.  # noqa: E501
        """
        pass

    def test_remove_relation_type(self):
        """Test case for remove_relation_type

        Removes relation type identified by given UUID.  # noqa: E501
        """
        pass

    def test_remove_relation_types(self):
        """Test case for remove_relation_types

        Removes multiple relation types.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
